import { Link } from 'react-router-dom';
import routes from './routes';
import { hashRouter } from './Router';

let routeArr = [];

// 菜单是否显示
// 没有 meta 或者 meta.title 为空, 或者 meta.hideInMenu = true 的 都不显示
const isShow = item => item.meta && item.meta.title && !item.meta.hideInMenu;

const hasChildren = (list) => {
  if (!list || list.length < 1) return false;

  // 如果子元素全部都是不显示的, 说明子菜单不需要显示
  return list.filter(it => !isShow(it)).length !== list.length;
}

const getPath = (parent, current = '') => {
  if (current.indexOf('/') === 0 || current.indexOf('http') === 0) return current;
  return `${parent}/${current}`.replace(/\/\//g, '/');
}

const getMenuItems = (dts = [], fullPath = '/') => {
  return dts.map(item => {
    const path = getPath(fullPath, item.path);

    //
    if (!isShow(item)) return false;
    
    const children = hasChildren(item.children) ? getMenuItems(item.children, path) : false;

    // 坑爹 react-router v6 不支持 hash 路由的 target 跳转
    const label = hashRouter && item.meta && item.meta.target === '_blank' ?
      <a href={`${window.location.pathname}#${path}`} target={item.meta.target}>{item.meta.title}</a>
      : <Link to={path} target={item.meta.target}>{item.meta.title}</Link>;

    return Object.assign(
      {
        key: path,
        label,
        title: item.meta.title,
        icon: item.meta.icon,
      },
      children && { children },
    )
  }).filter(Boolean);
}

const flatten = (routes, parent) => {
  (routes || []).forEach((route) => {
    const path = getPath(parent, route.path);
    routeArr.push({
      ...route,
      path
    });

    if (route.children) {
      flatten(route.children, path);
    }
  });
}

const getItems = () => getMenuItems(routes[0]?.children);
const getRouteArr = () => {
  if (routeArr.length < 1) {
    flatten(routes, '/');
  }
  return routeArr;
}
// 
export {
  getItems,
  getRouteArr,
};
